;;; -*- Lisp -*-

(defpackage #:clocc-port-system
  (:use #:common-lisp #:asdf))
(in-package #:clocc-port-system)

(defclass gray-streams (component) ())

(defmethod perform ((operation compile-op) (component gray-streams))
  #+cmu (require :cmucl-graystream)
  t)

(defmethod perform ((operation load-op) (component gray-streams))
  #+cmu (require :cmucl-graystream)
  t)

(defclass legacy-cl-source-file (cl-source-file)
    ()
  (:documentation
   "Common Lisp source code module with (non-style) warnings.
In contrast to CL-SOURCE-FILE, this class does not think that such warnings
indicate failure."))

(defmethod perform ((operation compile-op) (c legacy-cl-source-file))
  (let ((source-file (component-pathname c))
	(output-file (car (output-files operation c)))
	(warnings-p nil)
	(failure-p nil))
    (setf (asdf::component-property c 'last-compiled) nil)
    (handler-bind ((warning (lambda (c)
			      (declare (ignore c))
			      (setq warnings-p t)))
		   ;; _not_ (or error (and warning (not style-warning)))
		   (error (lambda (c)
			    (declare (ignore c))
			    (setq failure-p t))))
      (compile-file source-file
		    :output-file output-file))
    ;; rest of this method is as for CL-SOURCE-FILE
    (setf (asdf::component-property c 'last-compiled) (file-write-date output-file))
    (when warnings-p
      (case (asdf::operation-on-warnings operation)
	(:warn (warn "COMPILE-FILE warned while performing ~A on ~A"
		     c operation))
	(:error (error 'compile-warned :component c :operation operation))
	(:ignore nil)))
    (when failure-p
      (case (asdf::operation-on-failure operation)
	(:warn (warn "COMPILE-FILE failed while performing ~A on ~A"
		     c operation))
	(:error (error 'compile-failed :component c :operation operation))
	(:ignore nil)))))

(defsystem clocc-port
  :components ((:gray-streams "vendor-gray-streams")
	       (:legacy-cl-source-file "ext")
	       (:file "gray" :depends-on ("ext" "vendor-gray-streams"))
	       (:file "net" :depends-on ("ext" "sys"))
	       (:file "path" :depends-on ("ext"))
	       (:legacy-cl-source-file "proc" :depends-on ("ext"))
	       (:legacy-cl-source-file "shell" :depends-on ("ext"))
	       (:file "sys" :depends-on ("ext" "path")))
  :depends-on (#+(or cmu sbcl) :db-sockets))
